@@ -43,7 +43,7 @@ class SpeechBrainEmbeddings:
         if not SPEECHBRAIN_AVAILABLE:
             raise ModuleNotFoundError(
                 "`speechbrain` is not installed. "
-                "Please install senselab audio dependencies using `pip install senselab['audio']`."
+                "Please install senselab audio dependencies using `pip install 'senselab[audio]'`."
             )
 
         device, _ = _select_device_and_dtype(
@@ -82,7 +82,7 @@ class SpeechBrainEmbeddings:
         if not SPEECHBRAIN_AVAILABLE:
             raise ModuleNotFoundError(
                 "`speechbrain` is not installed. "
-                "Please install senselab audio dependencies using `pip install senselab['audio']`."
+                "Please install senselab audio dependencies using `pip install 'senselab[audio]'`."
             )
 
         if model is None:
